@@ -1,8 +1,12 @@
 """
 Provider for Patreon
 """
+
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
+from allauth.socialaccount.providers.vimeo_oauth2.views import (
+    VimeoOAuth2Adapter,
+)
 
 
 class VimeoOAuth2Account(ProviderAccount):
@@ -13,6 +17,7 @@ class VimeoOAuth2Provider(OAuth2Provider):
     id = "vimeo_oauth2"
     name = "Vimeo"
     account_class = VimeoOAuth2Account
+    oauth2_adapter_class = VimeoOAuth2Adapter
 
     def get_default_scope(self):
         return ["public", "private"]
